@@ -221,14 +221,14 @@ def get_markdown_info_with_jira_format(url, file):
 
 def main(args=None):
     read_config()
-    card_no = 'OTRT-285'
-    file_url = config['file_base_uri'] + 'i1'
-    file_name = card_no + ".md"
 
     if len(sys.argv) == 3:
         file_url = config['file_base_uri'] + sys.argv[1]
-        file_name = sys.argv[2] + ".md"
+        card_no = sys.argv[2]
+        file_name = card_no + ".md"
+        print(card_no)
         jira_desc = get_markdown_info_with_jira_format(file_url, file_name)
+        print(jira_desc)
         edit_jira_card(card_no, jira_desc)
         return 0
     else:
@@ -236,7 +236,10 @@ def main(args=None):
         files = os.listdir(file_url)  # 得到文件夹下的所有文件名称
         for file_name in files:  # 遍历文件夹
             if not os.path.isdir(file_name):
+                card_no = file_name.replace(".md", "")
+                print(card_no)
                 jira_desc = get_markdown_info_with_jira_format(file_url, file_name)
+                print(jira_desc)
                 edit_jira_card(card_no, jira_desc)
         return 0
 
